@@ -1,13 +1,15 @@
 __title__ = 'strainer'
-__version__ = '1.0.0'
+__version__ = '1.3.0'
 __author__ = 'Alex Kessinger'
 __license__ = 'Apache 2.0'
 __copyright__ = 'Copyright 2016 Alex Kessiger'
 
-from .structure import (serializer, many, child, field, dict_field)
+from .structure import (serializer, many, child, field, dict_field, multiple_field)
 from .exceptions import ValidationException
+from .context import SerializationContext, check_context
 from strainer import formatters
 from strainer import validators
 
 __all__ = (serializer, many, child, field, dict_field,
-           ValidationException, formatters, validators)
+           ValidationException, formatters, validators, multiple_field,
+           SerializationContext, check_context)
